@@ -80,12 +80,12 @@ def schedule_SA(ini_temp=1000, cool_rate=0.99, termi_num=30):
 		else:
 			termination_count = 0
 
-		print("The current score is:" + str(curr_score))
+		#print("The current score is:" + str(curr_score))
 		T = T * alpha
 	t1 = time.time()
 	print("Time Taken for SA: " + str(t1-t0) + ' seconds')
 
-	sol_list = [soln, schedule_days]
-	thread = Thread(target=show_timetable, args=[sol_list])
-	thread.start()
-	print(curr_score)
\ No newline at end of file
+	# sol_list = [soln, schedule_days]
+	# thread = Thread(target=show_timetable, args=[sol_list])
+	# thread.start()
+	# print(curr_score)
\ No newline at end of file
